@@ -1,3 +1,5 @@
+import gzip
+import io
 import json
 import os
 import re
@@ -26,7 +28,8 @@ def oauth1_token_dict() -> dict:
         oauth_token="7fdff19aa9d64dda83e9d7858473aed1",
         oauth_token_secret="49919d7c4c8241ac93fb4345886fbcea",
         mfa_token="ab316f8640f3491f999f3298f3d6f1bb",
-        mfa_expiration_timestamp="2023-08-02 05:56:10.000",
+        mfa_expiration_timestamp="2024-08-02 05:56:10.000",
+        domain="garmin.com",
     )
 
 
@@ -102,6 +105,17 @@ def sanitize_request(request):
 
 
 def sanitize_response(response):
+    try:
+        encoding = response["headers"].pop("Content-Encoding")
+    except KeyError:
+        ...
+    else:
+        if encoding[0] == "gzip":
+            body = response["body"]["string"]
+            buffer = io.BytesIO(body)
+            body = gzip.GzipFile(fileobj=buffer).read()
+            response["body"]["string"] = body
+
     for key in ["set-cookie", "Set-Cookie"]:
         if key in response["headers"]:
             cookies = response["headers"][key]
